﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace DisplayASimpleMapForWPF
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.DecimalDegree;
            Map1.CurrentExtent = new RectangleShape(-10, 30, 30, 10);
            InMemoryFeatureLayer roadLayer = new InMemoryFeatureLayer();
            roadLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Canal1;
            roadLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            LineShape roadLine1 = new LineShape();
            roadLine1.Vertices.Add(new Vertex(0, 0));
            roadLine1.Vertices.Add(new Vertex(0, 10));
            roadLine1.Vertices.Add(new Vertex(10, 10));
            roadLine1.Vertices.Add(new Vertex(10, 20));
            roadLayer.InternalFeatures.Add(new Feature(roadLine1));

            InMemoryFeatureLayer newroadLayer = new InMemoryFeatureLayer();
            newroadLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Highway1;
            newroadLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City6;
            newroadLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            Map1.MapClick += new EventHandler<MapClickWpfMapEventArgs>(Map1_MapClick);

            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add("RoadLayer", roadLayer);
            Map1.Overlays.Add("RoadOverlay", overlay);

            Map1.Refresh();
        }

        void Map1_MapClick(object sender, MapClickWpfMapEventArgs e)
        {
            LayerOverlay overlay = Map1.Overlays["RoadOverlay"] as LayerOverlay;
            InMemoryFeatureLayer roadlayer = overlay.Layers[0] as InMemoryFeatureLayer;
            Collection<Feature> nearestFeatures = roadlayer.QueryTools.GetFeaturesNearestTo(e.WorldLocation, GeographyUnit.DecimalDegree, 1, ReturningColumnsType.NoColumns);
            if (nearestFeatures.Count > 0)
            {
                LineShape nearestLine = nearestFeatures[0].GetShape() as LineShape;
                PointShape nearestPoint = (PointShape)nearestLine.GetClosestPointTo(e.WorldLocation, GeographyUnit.DecimalDegree);
                LineShape newLine = new LineShape();
                newLine.Vertices.Add(new Vertex(e.WorldLocation));
                newLine.Vertices.Add(new Vertex(nearestPoint));
                roadlayer.InternalFeatures.Add(new Feature(newLine));
            }
            Map1.Refresh();
        }
    }
}
